@@ -722,9 +722,10 @@ gnutls_priority_init (gnutls_priority_t * priority_cache,
 	}
       else if (broken_list[i][0] == '%')
 	{
-	  if (strcasecmp (&broken_list[i][1], "COMPAT") == 0)
+	  if (strcasecmp (&broken_list[i][1], "COMPAT") == 0) {
 	    (*priority_cache)->no_padding = 1;
-	  else if (strcasecmp (&broken_list[i][1],
+	    (*priority_cache)->allow_large_records = 1;
+	  } else if (strcasecmp (&broken_list[i][1],
 			       "VERIFY_ALLOW_SIGN_RSA_MD5") == 0)
 	    {
 	      prio_add (&(*priority_cache)->sign_algo, GNUTLS_SIGN_RSA_MD5);
